Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(90)

Unified Diff: include/v8.h

Issue 21803002: Add size_t length argument to v8::ArrayBuffer::Allocator::Free. (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Shared buold fixed Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/api.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/v8.h
diff --git a/include/v8.h b/include/v8.h
index 11fccdf023999ff3c3a8acf425c669be29cae54c..311ad434de8516dff174558f15dfe8ae45ad8179 100644
--- a/include/v8.h
+++ b/include/v8.h
@@ -2425,10 +2425,20 @@ class V8EXPORT ArrayBuffer : public Object {
}
/**
* Free the memory pointed to |data|. That memory is guaranteed to be
* previously allocated by |Allocate|.
*/
- virtual void Free(void* data) = 0;
+ virtual void Free(void* data, size_t length) {
+ // Override with call to |Free(void*)| for compatibility
+ // with legacy version.
+ Free(data);
+ }
+
+ /**
+ * Deprecated. Never called directly by V8.
+ * For compatibility with legacy version of this interface.
+ */
+ virtual void Free(void* data);
};
/**
« no previous file with comments | « no previous file | src/api.cc » ('j') | no next file with comments »
@@ -2425,10 +2425,20 @@ class V8EXPORT ArrayBuffer : public Object {
}
/**
- * Free the memory pointed to |data|. That memory is guaranteed to be
- * previously allocated by |Allocate|.
+ * Free the memory block of size |length|, pointed to by |data|.
+ * That memory is guaranteed to be previously allocated by |Allocate|.
*/

Powered by Google App Engine
This is Rietveld 408576698